@@ -65,7 +65,7 @@ class DatabaseFeatures(BaseDatabaseFeatures):
     #has_bulk_insert = False
     # DateTimeField doesn't support timezones, only DateTimeOffsetField
     supports_timezones = False
-    supports_sequence_reset = False    
+    supports_sequence_reset = False
     supports_tablespaces = True
     ignores_nulls_in_unique_constraints = False
     can_introspect_autofield = True
@@ -129,6 +129,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
             self.unicode_results = options.get('unicode_results', False)
             self.encoding = options.get('encoding', 'utf-8')
             self.driver_supports_utf8 = options.get('driver_supports_utf8', None)
+            self.driver_needs_utf8 = options.get('driver_needs_utf8', None)
 
             # make lookup operators to be collation-sensitive if needed
             self.collation = options.get('collation', None)
@@ -152,8 +153,8 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         self.creation = DatabaseCreation(self)
         self.introspection = DatabaseIntrospection(self)
         self.validation = BaseDatabaseValidation(self)
-
         self.connection = None
+        
 
     def get_connection_params(self):
         settings_dict = self.settings_dict
@@ -288,7 +289,11 @@ class DatabaseWrapper(BaseDatabaseWrapper):
             # considered the first day of the week (to be consistent with the
             # Django convention for the 'week_day' Django lookup) if the user
             # hasn't told us otherwise
-            cursor.execute("SET DATEFORMAT ymd; SET DATEFIRST %s" % self.datefirst)
+
+            if not self.ops.is_db2:
+                # IBM's DB2 doesn't support this syntax and a suitable
+                # equivalent could not be found.
+                cursor.execute("SET DATEFORMAT ymd; SET DATEFIRST %s" % self.datefirst)
             if self.ops.sql_server_ver < 2005:
                 self.creation.data_types['TextField'] = 'ntext'
                 self.features.can_return_id_from_insert = False
