@@ -1,6 +1,10 @@
 import datetime
 import decimal
 import time
+try:
+    import pytz
+except:
+    pytz = None
 
 from django.conf import settings
 from django.db.backends import BaseDatabaseOperations
@@ -20,6 +24,33 @@ class DatabaseOperations(BaseDatabaseOperations):
         self.connection = connection
         self._ss_ver = None
         self._ss_edition = None
+        self._is_db2 = None
+        
+    @property
+    def is_db2(self):
+        if self._is_db2 is None:
+            cur = self.connection.cursor()
+            try:
+                cur.execute("SELECT * FROM SYSIBM.COLUMNS FETCH FIRST 1 ROWS ONLY")
+                self._is_db2 = True
+            except Exception:
+                self._is_db2 = False
+
+        return self._is_db2
+    
+    @property
+    def left_sql_quote(self):
+        if self.is_db2:
+            return '{'
+        else:
+            return '['
+    
+    @property
+    def right_sql_quote(self):
+        if self.is_db2:
+            return '}'
+        else:
+            return ']'
 
     def _get_sql_server_ver(self):
         """
@@ -28,9 +59,11 @@ class DatabaseOperations(BaseDatabaseOperations):
         if self._ss_ver is not None:
             return self._ss_ver
         cur = self.connection.cursor()
-        cur.execute("SELECT CAST(SERVERPROPERTY('ProductVersion') as varchar)")
-        ver_code = cur.fetchone()[0]
-        ver_code = int(ver_code.split('.')[0])
+        ver_code = None
+        if not self.is_db2:
+            cur.execute("SELECT CAST(SERVERPROPERTY('ProductVersion') as varchar)")
+            ver_code = cur.fetchone()[0]
+            ver_code = int(ver_code.split('.')[0])
         if ver_code >= 11:
             self._ss_ver = 2012
         elif ver_code == 10:
@@ -61,7 +94,6 @@ class DatabaseOperations(BaseDatabaseOperations):
         else:
             return "DATEPART(%s, %s)" % (lookup_type, field_name)
 
-
     def date_trunc_sql(self, lookup_type, field_name):
         return "DATEADD(%s, DATEDIFF(%s, 0, %s), 0)" % (lookup_type, lookup_type, field_name)
         
@@ -119,6 +151,8 @@ class DatabaseOperations(BaseDatabaseOperations):
         to cast it before using it in a WHERE statement. Note that the
         resulting string should contain a '%s' placeholder for the column being
         searched against.
+
+        TODO: verify that db_type and internal_type do not affect T-SQL CAST statement
         """
         if self.sql_server_ver < 2005 and db_type and db_type.lower() == 'ntext':
             return 'CAST(%s as nvarchar)'
@@ -180,9 +214,9 @@ class DatabaseOperations(BaseDatabaseOperations):
         Returns a quoted version of the given table, index or column name. Does
         not quote the given name if it's already been quoted.
         """
-        if name.startswith('[') and name.endswith(']'):
+        if name.startswith(self.left_sql_quote) and name.endswith(self.right_sql_quote):
             return name # Quoting once is enough.
-        return '[%s]' % name
+        return '%s%s%s' % (self.left_sql_quote, name, self.right_sql_quote)
 
     def random_function_sql(self):
         """
